@@ -32,7 +32,10 @@ using namespace std;
 namespace Music
 {
 	//! Seek for the period (relative to sampling rate)
-	double GetAverageWaveLengthFromApprox(const std::deque<double>& queue, size_t approx, int n, double AFreq=GetAFreq(), int sampling_rate=GetSamplingRate());
+	double GetAverageWaveLengthFromApproxEnergy(const std::deque<double>& queue, double approx, int n);
+
+	//! Seek for the period (relative to sampling rate)
+	double GetAveragePeriodFromApprox(const std::deque<double>& queue, int approx, int n);
 
 	//! Get a sample of the wave form (relative to sampling rate)
 	void GetWaveSample(const std::deque<double>& queue, size_t wave_length, std::deque<double>& sample);
