@@ -24,16 +24,18 @@
 using namespace std;
 #include <Music/CFFTW3.h>
 // using namespace Music;
-#include <qgl.h>
+#include <QOpenGLWidget>
 #include <qspinbox.h>
 #include <qaction.h>
 #include "View.h"
 
-class GLFT : public QGLWidget, public View
+class GLFT : public QOpenGLWidget, public View
 {
 	Q_OBJECT
 
-	virtual void mouseReleaseEvent(QMouseEvent* e){View::mouseReleaseEvent(e);}
+    QFont m_font;
+
+    virtual void mouseReleaseEvent(QMouseEvent* e){View::mouseReleaseEvent(e);}
 	virtual void mousePressEvent(QMouseEvent* e);
 	virtual void mouseDoubleClickEvent(QMouseEvent* e);
 	virtual void mouseMoveEvent(QMouseEvent* e);
