@@ -33,7 +33,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Credits</source>
-        <translation>Έπαινοι</translation>
+        <translation>Μνείες</translation>
     </message>
     <message>
         <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
@@ -64,7 +64,7 @@ p, li { white-space: pre-wrap; }
     <name>ConfigForm</name>
     <message>
         <source>Sampling rate</source>
-        <translation>Ρυμός δειγματολειψίας</translation>
+        <translation>Ρυθμός δειγματολειψίας</translation>
     </message>
     <message>
         <source>set to max</source>
@@ -124,7 +124,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>default</source>
-        <translation>default</translation>
+        <translation>προεπιλογή</translation>
     </message>
     <message>
         <source>OSS</source>
@@ -785,7 +785,7 @@ p</source>
     </message>
     <message>
         <source>Space</source>
-        <translation>Διάστημα</translation>
+        <translation>Κενό</translation>
     </message>
     <message>
         <source>Configure</source>
@@ -939,7 +939,7 @@ green   : a note is beeing analyzed and analysis conditions are OK.</source>
     <name>QObject</name>
     <message>
         <source>default</source>
-        <translation>προκαθορισμένο</translation>
+        <translation>προεπιλογή</translation>
     </message>
     <message>
         <source>%1</source>
