@@ -6,7 +6,7 @@
     <message>
         <location filename="../ui/aboutbox.ui" line="14"/>
         <source>About FMIT...</source>
-        <translation type="unfinished"></translation>
+        <translation>O FMIT...</translation>
     </message>
     <message>
         <location filename="../ui/aboutbox.ui" line="28"/>
@@ -58,17 +58,17 @@ p, li { white-space: pre-wrap; }
     <message>
         <location filename="../ui/ConfigForm.ui" line="14"/>
         <source>Configuration</source>
-        <translation type="unfinished"></translation>
+        <translation>Konfiguracja</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="46"/>
         <source>General</source>
-        <translation type="unfinished"></translation>
+        <translation>Ogólne</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="60"/>
         <source>Start in full-screen</source>
-        <translation type="unfinished"></translation>
+        <translation>Uruchamiaj w trybie pełnoekranowym</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="82"/>
@@ -137,7 +137,7 @@ p, li { white-space: pre-wrap; }
     <message>
         <location filename="../ui/ConfigForm.ui" line="332"/>
         <source>JACK</source>
-        <translation type="unfinished"></translation>
+        <translation>JACK</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="346"/>
@@ -163,12 +163,12 @@ p, li { white-space: pre-wrap; }
         <location filename="../ui/ConfigForm.ui" line="723"/>
         <location filename="../ui/ConfigForm.ui" line="835"/>
         <source>Sampling rate</source>
-        <translation type="unfinished"></translation>
+        <translation>Częstotliwość próbkowania</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="443"/>
         <source>ALSA</source>
-        <translation type="unfinished"></translation>
+        <translation>ALSA</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="160"/>
@@ -186,7 +186,7 @@ latin: Do Re Mi Fa Sol La Si</source>
         <location filename="../ui/ConfigForm.ui" line="689"/>
         <location filename="../ui/ConfigForm.ui" line="801"/>
         <source>Device name</source>
-        <translation type="unfinished"></translation>
+        <translation>Nazwa urządzenia</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="542"/>
@@ -194,7 +194,7 @@ latin: Do Re Mi Fa Sol La Si</source>
         <location filename="../ui/ConfigForm.ui" line="770"/>
         <location filename="../ui/ConfigForm.ui" line="882"/>
         <source>Do not use a too big sampling rate. 22050Hz should be largely enough in most cases.</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie używaj zbyt wielkiej częstotliwości próbkowania. 22050Hz powinno być odpowiednie w większości przypadków.</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="559"/>
@@ -236,7 +236,7 @@ latin: Do Re Mi Fa Sol La Si</source>
         <location filename="../ui/ConfigForm.ui" line="703"/>
         <location filename="../ui/ConfigForm.ui" line="815"/>
         <source>default</source>
-        <translation type="unfinished"></translation>
+        <translation>Domyślne</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="52"/>
@@ -248,7 +248,7 @@ latin: Do Re Mi Fa Sol La Si</source>
     <message>
         <location filename="../ui/ConfigForm.ui" line="67"/>
         <source>Auto-save configuration and layout on exit</source>
-        <translation type="unfinished"></translation>
+        <translation>Zachowaj konfigurację i układ po zamknięciu</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="76"/>
@@ -261,12 +261,12 @@ latin: Do Re Mi Fa Sol La Si</source>
     <message>
         <location filename="../ui/ConfigForm.ui" line="128"/>
         <source>Transposition</source>
-        <translation type="unfinished"></translation>
+        <translation>Transpozycja</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="198"/>
         <source>German</source>
-        <translation type="unfinished"></translation>
+        <translation>Niemiecki</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="203"/>
@@ -322,12 +322,12 @@ latin: Do Re Mi Fa Sol La Si</source>
     <message>
         <location filename="../ui/ConfigForm.ui" line="385"/>
         <source>automaticaly connect to...</source>
-        <translation type="unfinished"></translation>
+        <translation>automatycznie podłącz do...</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="421"/>
         <source>JACK sampling rate</source>
-        <translation type="unfinished"></translation>
+        <translation>Częstotliwość próbkowania JACK</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="451"/>
@@ -389,7 +389,7 @@ Do not use a too big sampling rate. 22050Hz should be enough in most cases.</sou
     <message>
         <location filename="../ui/ConfigForm.ui" line="787"/>
         <source>Qt</source>
-        <translation type="unfinished"></translation>
+        <translation>Qt</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="916"/>
@@ -480,7 +480,7 @@ The smaller the value, the faster the tuner. However, by decreasing the value, t
         <location filename="../ui/ConfigForm.ui" line="1586"/>
         <location filename="../ui/ConfigForm.ui" line="1589"/>
         <source>Discard any changes and quit the configuration panel</source>
-        <translation type="unfinished"></translation>
+        <translation>Porzuć wszystkie zmiany i zamknij panel konfiguracji</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="932"/>
@@ -605,7 +605,7 @@ Choose the number of harmonics to use.</source>
     <message>
         <location filename="../ui/ConfigForm.ui" line="1480"/>
         <source>Latency</source>
-        <translation type="unfinished"></translation>
+        <translation>Opóźnienie</translation>
     </message>
     <message>
         <location filename="../ui/ConfigForm.ui" line="1544"/>
@@ -629,7 +629,7 @@ Choose the number of harmonics to use.</source>
         <location filename="../src/CustomInstrumentTunerForm.cpp" line="1054"/>
         <location filename="../src/CustomInstrumentTunerForm.cpp" line="1067"/>
         <source>Restore Factory Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Przywróć Ustawienia Domyślne</translation>
     </message>
     <message>
         <location filename="../src/CustomInstrumentTunerForm.cpp" line="1054"/>
@@ -714,7 +714,7 @@ It can useful to put it higher than -35 to avoid disturbance from the sector ali
     <message>
         <location filename="../src/modules/GLErrorHistory.cpp" line="75"/>
         <source>Error history</source>
-        <translation type="unfinished"></translation>
+        <translation>Historia błędów</translation>
     </message>
     <message>
         <location filename="../src/modules/GLErrorHistory.cpp" line="82"/>
@@ -739,7 +739,7 @@ It can useful to put it higher than -35 to avoid disturbance from the sector ali
     <message>
         <location filename="../src/modules/GLErrorHistory.cpp" line="229"/>
         <source>Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Błąd</translation>
     </message>
 </context>
 <context>
@@ -1072,7 +1072,7 @@ green   : a note is beeing analyzed and analysis conditions are OK.</source>
     <message>
         <location filename="../ui/InstrumentTunerForm.ui" line="422"/>
         <source>Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Ustawienia</translation>
     </message>
     <message>
         <location filename="../ui/InstrumentTunerForm.ui" line="444"/>
@@ -1110,12 +1110,12 @@ green   : a note is beeing analyzed and analysis conditions are OK.</source>
     <message>
         <location filename="../ui/InstrumentTunerForm.ui" line="477"/>
         <source>Save settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Zapisz ustawienia</translation>
     </message>
     <message>
         <location filename="../ui/InstrumentTunerForm.ui" line="486"/>
         <source>Ctrl+S</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+S</translation>
     </message>
     <message>
         <location filename="../ui/InstrumentTunerForm.ui" line="498"/>
@@ -1195,7 +1195,7 @@ green   : a note is beeing analyzed and analysis conditions are OK.</source>
     <message>
         <location filename="../src/CaptureThread.cpp" line="368"/>
         <source>default</source>
-        <translation type="unfinished"></translation>
+        <translation>Domyślne</translation>
     </message>
     <message>
         <location filename="../src/modules/View.cpp" line="86"/>
