@@ -57,7 +57,7 @@ p, li { white-space: pre-wrap; }
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- John Anderson pela ideia do módulo microtonal&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Scott Bahling pelas escalas em cents&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Jacob Shapiro pela ajuda em fazer o FMIT funcionar no Windows/Cygwin.&lt;/p&gt;
-&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;- Tradutores: Omega9 (russo), skarmoutsosv (grego), Pindaro and dsboger (português de Portugal e do Brasil), Florian Maier (alemão).&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Equipe FFTW3&lt;/span&gt;&lt;/a&gt; pela Transformada (muito) Rápida de Fourier.&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Equipe Qt&lt;/span&gt;&lt;/a&gt; pela biblioteca de interface gráfica.&lt;br /&gt;&lt;br /&gt;Qualquer tipo de contribuição é muito bem-vinda!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;- Tradutores: Omega9 (russo), skarmoutsosv (grego), Pindaro and dsboger (português de Portugal e do Brasil), Florian Maier (alemão).&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Equipa FFTW3&lt;/span&gt;&lt;/a&gt; pela Transformada (muito) Rápida de Fourier.&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Equipa Qt&lt;/span&gt;&lt;/a&gt; pela biblioteca de interface gráfica.&lt;br /&gt;&lt;br /&gt;Qualquer tipo de contribuição é muito bem-vinda!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
 </context>
 <context>
@@ -134,7 +134,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>The capture system</source>
-        <translation>Sistema de captura</translation>
+        <translation>O sistema de captura</translation>
     </message>
     <message>
         <source>Selected the capture system (e.g. JACK, ALSA, OSS, PortAudio)</source>
@@ -564,11 +564,11 @@ Useful to convert note names to a corresponding transposing instrument (e.g. %2
     </message>
     <message>
         <source>- Press left mouse button to move the view</source>
-        <translation>Pressione o botão esquerdo do mouse para mover a visualização</translation>
+        <translation>Pressione o botão esquerdo do rato para mover a visualização</translation>
     </message>
     <message>
         <source>- Press SHIFT key and left mouse button to zoom in and out</source>
-        <translation>Pressione o botão SHIFT mais o botão esquerdo do mouse para aumentar ou diminuir o zoom</translation>
+        <translation>Pressione o botão SHIFT mais o botão esquerdo do rato para aumentar ou diminuir o zoom</translation>
     </message>
     <message>
         <source>- Double-click to reset the view</source>
@@ -606,7 +606,7 @@ Useful to convert note names to a corresponding transposing instrument (e.g. %2
     </message>
     <message>
         <source>Auto scale</source>
-        <translation>Auto escala</translation>
+        <translation>Escala automática</translation>
     </message>
     <message>
         <source>Scale factor</source>
@@ -668,7 +668,7 @@ Useful to convert note names to a corresponding transposing instrument (e.g. %2
     </message>
     <message>
         <source>Scale auto</source>
-        <translation>Auto escala</translation>
+        <translation>Escala automática</translation>
     </message>
     <message>
         <source>Scale min</source>
@@ -759,10 +759,10 @@ grey     : the capture system is OK, but there is not enough sound.
 orange : the analysis conditions are bad (like saturation)
 green   : a note is beeing analyzed and analysis conditions are OK.</source>
         <translation>Segundo as seguintes cores:
-vermelho: o sistema de captura não está funcionando.
-cinza: o sistema de captura está OK, porém não há som suficiente.
+vermelho: o sistema de captura não está a funcionar.
+cinzenta: o sistema de captura está OK, porém não há som suficiente.
 laranja: as condições de análise estão ruins (p.ex. saturação).
-verde: a nota está sendo analisada e as condições de análise estão OK.</translation>
+verde: a nota está a ser analisada e as condições de análise estão OK.</translation>
     </message>
     <message>
         <source>Note Stability</source>
@@ -826,7 +826,7 @@ verde: a nota está sendo analisada e as condições de análise estão OK.</tra
     </message>
     <message>
         <source>Configure</source>
-        <translation>Configurações</translation>
+        <translation>Configurar</translation>
     </message>
     <message>
         <source>Save settings</source>
